@@ -73,6 +73,6 @@ class TLMRunner(Runner):
     def __call__(self, input_tensors: Dict[str, np.ndarray]) -> Dict[str, np.ndarray]:
         """Perform TLM run for a given input."""
         # pylint: disable=import-outside-toplevel
-        from tpu_commands.frontend.design.api import tlm
+        from tpu_compiler_frontend.design.api import tlm
         _, output_tensors = tlm(self._tlm_program, input_tensors)
         return output_tensors
