@@ -23,7 +23,8 @@ TINY_YOLO3_ANCHORS = np.array([
 def draw_boxes(
         img: Image,
         boxes: Any,
-        font: str = '/usr/share/fonts/liberation/LiberationSans-Regular.ttf') -> Image:
+        font: str = '/usr/share/fonts/liberation/LiberationSans-Regular.ttf',
+        class_names: list = CLASS_NAMES) -> Image:
     """
     Draws detected boxes on a single image.
 
@@ -35,6 +36,8 @@ def draw_boxes(
         boxes that should be drawn (in dict or np.ndarray format)
     font
         any font
+    class_names
+        list of class names
     Returns
     -------
     Pillow image with drawn boxes
@@ -42,7 +45,7 @@ def draw_boxes(
     draw = ImageDraw.Draw(img)
     font = ImageFont.truetype(font=font,
                               size=(img.size[0] + img.size[1]) // 100)
-    colors = get_spaced_colors(len(CLASS_NAMES))
+    colors = get_spaced_colors(len(class_names))
     if isinstance(boxes, dict):
         for cls in list(boxes.keys()):
             box_ = boxes[cls]
@@ -57,7 +60,7 @@ def draw_boxes(
                     xy_coords[0], xy_coords[1] = xy_coords[0] + tick, xy_coords[1] + tick
                     xy_coords[2], xy_coords[3] = xy_coords[2] - tick, xy_coords[3] - tick
                     draw.rectangle(xy_coords, outline=tuple(color))
-                text = '{} {:.1f}%'.format(CLASS_NAMES[cls],
+                text = '{} {:.1f}%'.format(class_names[cls],
                                            confidence * 100)
                 text_size = draw.textsize(text, font=font)
                 draw.rectangle(
@@ -83,9 +86,9 @@ def draw_boxes(
                 xy_coords[2], xy_coords[3] = xy_coords[2] - tick, xy_coords[3] - tick
                 draw.rectangle([xy_coords[0], xy_coords[1], xy_coords[2], xy_coords[3]], outline=tuple(color))
             if box.shape[0] == 6:
-                text = '{} {:.1f}%'.format(CLASS_NAMES[class_], confidence * 100)
+                text = '{} {:.1f}%'.format(class_names[class_], confidence * 100)
             else:
-                text = '{}'.format(CLASS_NAMES[class_])
+                text = '{}'.format(class_names[class_])
             text_size = draw.textsize(text, font=font)
             draw.rectangle(
                 [x0_coord, y0_coord - text_size[1], x0_coord + text_size[0], y0_coord],
